==> OpenPatricianDisplay-0.6.0-RC1-sources.jar: ch/sahits/game/graphic/event/task/PostponedDisplayMessage.java <==
package ch.sahits.game.graphic.event.task;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.Prototype;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.event.TimedTask;
import ch.sahits.game.openpatrician.model.event.TimedUpdatableTaskList;
import com.google.common.eventbus.AsyncEventBus;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import javax.annotation.PostConstruct;

/**
 * Post a displayed message, but postpone it.
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 * Created on Feb 23, 2013
 *
 */
@Prototype
@ClassCategory({EClassCategory.DEPENDS_ON_SERIALIZED_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class PostponedDisplayMessage extends TimedTask {

	private final String messageKey;
    private final Object[] messageArgs;

    @Autowired
    private TimedUpdatableTaskList taskList;
    @Autowired
    @Qualifier("clientEventBus")
    private AsyncEventBus clientEventBus;


	public PostponedDisplayMessage(DateTime executionTime, String messageKey, Object...messageArgs) {
		super();
        setExecutionTime(executionTime);
		this.messageKey = messageKey;
        this.messageArgs = messageArgs;
	}
    @PostConstruct
    private void initialize() {
        taskList.add(this);
    }


	@Override
	public void run() {
		DisplayMessage msg = new DisplayMessage(messageKey, messageArgs);
        clientEventBus.post(msg);
	}

}

==> OpenPatricianDisplay-0.7.0-RC1-sources.jar: ch/sahits/game/graphic/event/task/PostponedDisplayMessage.java <==
package ch.sahits.game.graphic.event.task;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.Prototype;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.event.TimedTask;
import ch.sahits.game.openpatrician.model.event.TimedUpdatableTaskList;
import com.google.common.eventbus.AsyncEventBus;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import javax.annotation.PostConstruct;

/**
 * Post a displayed message, but postpone it.
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 * Created on Feb 23, 2013
 *
 */
@Prototype
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class PostponedDisplayMessage extends TimedTask {

	private final String messageKey;
    private final Object[] messageArgs;

    @Autowired
    private TimedUpdatableTaskList taskList;
    @Autowired
    @Qualifier("clientEventBus")
    @XStreamOmitField
    private AsyncEventBus clientEventBus;


	public PostponedDisplayMessage(DateTime executionTime, String messageKey, Object...messageArgs) {
		super();
        setExecutionTime(executionTime);
		this.messageKey = messageKey;
        this.messageArgs = messageArgs;
	}
    @PostConstruct
    private void initialize() {
        taskList.add(this);
    }


	@Override
	public void run() {
		DisplayMessage msg = new DisplayMessage(messageKey, messageArgs);
        clientEventBus.post(msg);
	}

}
